🚨Please review the
[guidelines for contributing](https://github.com/kiwicom/pytest-recording/blob/master/CONTRIBUTING.rst)
to this repository.

### Description

Please explain the changes you made here.

### Checklist

- [ ] Created tests which fail without the change (if possible)
- [ ] All tests passing
- [ ] Added a changelog entry
- [ ] Extended the README / documentation, if necessary
